#!/bin/sh
PATH=$HOME/bin:/bin:/usr/bin
export PATH
WIPES=wp$$

# "cd" to a writable area on the disk you want to securely wipe the free area

# any given arg causes verbose mode
case $# in
0)
	ROPT=
	;;
*)
	ROPT=-v
	;;
esac

# on interrupt, delete everything so far securely
trap "shred -u -f $ROPT -z -n6 $WIPES.*;exit" 2
# on hangup, quit, or term, just get out - not securely
trap "rm -f $ROPT $WIPES.*;exit" 1 3 15

# create tiny files getting bigger
N=1
S=1024
C=1
while :
do
	# force 8 digits to keep filenames sequential
	N=$( echo $N | awk '{printf "%08d", $1}')

	# Use "dd" since buffer sizes can be used
	dd if=/dev/zero bs=$S count=$C of=$WIPES.$N 2>/dev/null
	sync

	if [ -n "$ROPT" ]
	then
		ls -l $WIPES.$N
	fi
	# if no size of the final file, must have failed, assume diskfull
	if [ ! -s $WIPES.$N ]
	then
		break
	fi

	# next!
	N=`expr $N + 1`
	if [ $S -lt 1000000 ]
	then
		S=`expr $S + $S`
	else
		# once we get to 1Mb block size, change "dd" counts
		if [ $C -lt 50 ]
		then
			C=`expr $C + $C`
		fi
	fi
done

# delete the files securely
shred -u -f $ROPT -z -n6 $WIPES.*
